@@ -65,8 +65,6 @@ from evalml.problem_types import (
 from evalml.utils import get_time_index, infer_feature_types
 from evalml.utils.gen_utils import contains_all_ts_parameters
 
-_UNSUPPORTED_FREQUENCIES_STL_DECOMPOSER = ["A", "Y", "T", "AS", "YS"]
-
 
 def _get_label_encoder(X, y, problem_type, estimator_class, sampler_name=None):
     component = []
@@ -234,11 +232,8 @@ def _get_decomposer(X, y, problem_type, estimator_class, sampler_name=None):
         # If the time index frequency is uninferrable, STL will fail
         if time_index.freq is None:
             return components
-        freq = time_index.freq.name.split("-")[0]
-        if (
-            freq[-1] not in _UNSUPPORTED_FREQUENCIES_STL_DECOMPOSER
-            and freq not in _UNSUPPORTED_FREQUENCIES_STL_DECOMPOSER
-        ):
+        freq = time_index.freq.name
+        if STLDecomposer.is_freq_valid(freq):
             components.append(STLDecomposer)
     return components
 
@@ -369,6 +364,7 @@ def _make_pipeline_time_series(
     known_in_advance=None,
     exclude_featurizers=None,
     include_decomposer=True,
+    features=False,
 ):
     """Make a pipeline for time series problems.
 
@@ -390,6 +386,7 @@ def _make_pipeline_time_series(
            Valid options are "DatetimeFeaturizer", "EmailFeaturizer", "URLFeaturizer", "NaturalLanguageFeaturizer", "TimeSeriesFeaturizer"
         include_decomposer (bool): For time series regression problems, whether or not to include a decomposer in the generated pipeline.
             Defaults to True.
+        features (bool): Whether to add a DFSTransformer component to this pipeline.
 
     Returns:
         PipelineBase: TimeSeriesPipeline
@@ -412,6 +409,8 @@ def _make_pipeline_time_series(
         include_decomposer,
     )
 
+    dfs_transformer = [DFSTransformer] if features else []
+
     if known_in_advance:
         preprocessing_components = [SelectColumns] + preprocessing_components
         if (
@@ -420,7 +419,9 @@ def _make_pipeline_time_series(
         ):
             preprocessing_components.remove(DropNaNRowsTransformer)
     else:
-        preprocessing_components += [estimator]
+        preprocessing_components = (
+            dfs_transformer + preprocessing_components + [estimator]
+        )
 
     component_graph = PipelineBase._make_component_dict_from_component_list(
         preprocessing_components,
@@ -456,11 +457,15 @@ def _make_pipeline_time_series(
             parameters=parameters,
             custom_name="Pipeline",
         )
+        pre_pipeline_components = (
+            {"DFS Transformer": ["DFS Transformer", "X", "y"]} if features else None
+        )
         pipeline = _make_pipeline_from_multiple_graphs(
             [pipeline, kina_pipeline],
             DropNaNRowsTransformer if need_drop_nan else estimator,
             problem_type,
             parameters=parameters,
+            pre_pipeline_components=pre_pipeline_components,
             sub_pipeline_names={
                 kina_pipeline.name: "Known In Advance",
                 pipeline.name: "Not Known In Advance",
@@ -544,6 +549,7 @@ def make_pipeline(
             known_in_advance,
             exclude_featurizers,
             include_decomposer,
+            features,
         )
     else:
         preprocessing_components = _get_preprocessing_components(
